@@ -2,6 +2,7 @@
 // Based on MAME driver by Ernesto Corvi and various others
 
 #include "tiles_generic.h"
+#include "zet.h"
 #include "burn_ym2151.h"
 #include "konami_intf.h"
 #include "konamiic.h"
@@ -544,7 +545,7 @@ static void simpsons_objdma()
 	num_inactive = counter = 256;
 
 	do {
-		if ((*src & 0x8000) && (*src & 0xff))
+		if ((*src & BURN_ENDIAN_SWAP_INT16(0x8000)) && (*src & BURN_ENDIAN_SWAP_INT16(0xff)))
 		{
 			memcpy(dst, src, 0x10);
 			dst += 8;
@@ -562,7 +563,7 @@ static void DrvRecalcPal()
 	UINT8 r,g,b;
 	UINT16 *p = (UINT16*)DrvPalRAM;
 	for (INT32 i = 0; i < 0x1000 / 2; i++) {
-		UINT16 d = (p[i] << 8) | (p[i] >> 8);
+		UINT16 d = BURN_ENDIAN_SWAP_INT16((p[i] << 8) | (p[i] >> 8));
 
 		b = (d >> 10) & 0x1f;
 		g = (d >>  5) & 0x1f;
