@@ -2,6 +2,8 @@
 // Based on MAME driver by Manuel Abadia
 
 #include "tiles_generic.h"
+#include "sek.h"
+#include "zet.h"
 #include "burn_ym2151.h"
 #include "msm6295.h"
 #include "konamiic.h"
