@@ -2,6 +2,8 @@
 // Based on MAME driver David Haywood
 
 #include "tiles_generic.h"
+#include "sek.h"
+#include "zet.h"
 #include "burn_ym2610.h"
 
 static UINT8 *AllMem;
