@@ -2,6 +2,7 @@
 //Based on MAME Driver by Takahiro Nogi
 
 #include "tiles_generic.h"
+#include "zet.h"
 
 static UINT8 *AllMem;
 static UINT8 *MemEnd;
@@ -111,7 +112,7 @@ static INT32 DrvDraw()
 	UINT32 DrvPalette[2];
 
 	DrvPalette[0] = 0;
-	DrvPalette[1] = HighCol16(0xff, 0xff, 0xff, 0);
+	DrvPalette[1] = BurnHighCol(0xff, 0xff, 0xff, 0);
 
 	for (INT32 offs = 0x200; offs < 0x1e00; offs++)
 	{
