@@ -20,8 +20,7 @@ void ComputeGammaLUT()
 }
 
 // Standard callbacks for 16/24/32 bit color:
-// Standard callbacks for 16/24/32 bit color:
-static UINT32 __cdecl myHighCol15(INT32 r, INT32 g, INT32 b, INT32  /* i */)
+static UINT32 __cdecl HighCol15(INT32 r, INT32 g, INT32 b, INT32  /* i */)
 {
 	UINT32 t;
 	t =(r<<7)&0x7c00; // 0rrr rr00 0000 0000
@@ -30,7 +29,7 @@ static UINT32 __cdecl myHighCol15(INT32 r, INT32 g, INT32 b, INT32  /* i */)
 	return t;
 }
 
-static UINT32 __cdecl myHighCol16(INT32 r, INT32 g, INT32 b, INT32 /* i */)
+static UINT32 __cdecl HighCol16(INT32 r, INT32 g, INT32 b, INT32 /* i */)
 {
 	UINT32 t;
 	t =(r<<8)&0xf800; // rrrr r000 0000 0000
@@ -108,6 +107,7 @@ INT32 SetBurnHighCol(INT32 nDepth)
 		BurnHighCol = VidHighCol;
 	}
 */
+    printf("high color not implemented\n");
 	return 0;
 }
 
