@@ -108,6 +108,7 @@
 #include "driver.h"
 #include "state.h"
 #include "vez.h"
+#include "bitswap.h"
 //#include "emu.h"
 //#include "debugger.h"
 
@@ -471,17 +472,16 @@ void necInit(int cpu, int type)
 
 		case V30_TYPE:
 		{
-			nec_state->fetch_xor = 0;//BYTE_XOR_LE(0);
+			nec_state->fetch_xor = 0;
 			nec_state->chip_type=V30_TYPE;
 			nec_state->prefetch_size = 6;		/* 3 words */
 			nec_state->prefetch_cycles = 2;		/* two cycles per byte / four per word */
-			printf("NEC V30 Init\n");
 		}
 		break;
 
 		case V33_TYPE:
 		{
-			nec_state->fetch_xor = 0;//BYTE_XOR_LE(0);
+			nec_state->fetch_xor = 0;
 			nec_state->chip_type=V33_TYPE;
 			nec_state->prefetch_size = 6;
 			/* FIXME: Need information about prefetch size and cycles for V33.
