@@ -368,7 +368,7 @@ void shutdown()
 
 	}
 
-	int tmp;
+/*	int tmp;
     tmp = open("/proc/pandora/nub0/mode", O_WRONLY);
     write (tmp,nub0,10);
     close(tmp);
@@ -378,6 +378,58 @@ void shutdown()
     close(tmp);
     printf("Revert nub 1 to %s\n",nub1);
 
+    FILE * joyexists;
+    joyexists=NULL;
+    long timeout;
+    timeout=0;
+    int z=0;
+    if (strcmp(nub0,"absolute"))
+    {
+        while ((z==0) && (timeout<100000))
+        {
+        //   printf(".");
+            z=1;
+            joyexists=fopen("/dev/input/js0","r");
+            if (joyexists)
+            {
+                z=0;
+                fclose(joyexists);
+            }
+            usleep(20);
+
+            timeout++;
+        }
+        if (z==0)
+        {
+            fprintf(stdout,"js0 not deleted!\n");
+        }
+        else fprintf(stdout,"js0 removed\n");
+    }
+    joyexists=NULL;
+    timeout=0;
+    z=0;
+    if (strcmp(nub1,"absolute"))
+    {
+        while ((z==0) && (timeout<100000))
+        {
+        //   printf(".");
+            z=1;
+            joyexists=fopen("/dev/input/js1","r");
+            if (joyexists) {
+                z=0;
+                fclose(joyexists);
+            }
+            usleep(20);
+
+            timeout++;
+        }
+        if (z==0)
+        {
+            fprintf(stdout,"js1 not deleted!\n");
+        }
+        else fprintf(stdout,"js1 removed\n");
+    }*/
+
 	gp2x_terminate(config_options.option_frontend);
 
 
@@ -391,7 +443,7 @@ void load_keymap(char * nm)
 	signed long argd;
     char line[256];
     char fullpath[256];
-    strcpy(fullpath,"./config/games/");
+    strcpy(fullpath,"/home/user/.config/fba/");
     strcat(fullpath,nm);
     strcat(fullpath,".kmp");
     if ((f = fopen(fullpath,"r")) == NULL) f = fopen("/home/user/.config/fba/default.kmp", "r");
@@ -514,7 +566,7 @@ void run_fba_emulator(const char *fn)
 	printf("Attempt to initialise '%s'\n", BurnDrvGetTextA(DRV_FULLNAME));
 
 	memset (titlefb, 0, fwidth*fheight*2);
-	DrawString ("Finalburn Alpha for Pandora (v 0.2.97.21)", titlefb, 10, 20, fwidth);
+	DrawString ("Finalburn Alpha for Pandora (v 0.2.97.24)", titlefb, 10, 20, fwidth);
 	DrawString ("Based on FinalBurnAlpha", titlefb, 10, 35, fwidth);
 	DrawString ("Now loading ... ", titlefb, 10, 105, fwidth);
 	show_rom_loading_text("Open Zip", 0, 0);
@@ -550,6 +602,8 @@ void run_fba_emulator(const char *fn)
 	frame_count = 0;
 	GameLooping = true;
 
+	//bShowFPS = true;
+
 	if (BurnDrvGetFlags() & BDF_ORIENTATION_FLIPPED) printf("flipped!\n");
 
     {
